# Classic Database Benchmark Results

## Overview

Benchmarking 6 predefined database configurations:
- Read-Optimized: HASH_MAP + None
- Write-Optimized: LSM_TREE + DYNAMIC_ADJ_LIST
- Memory-Efficient: B_TREE + CSR
- Query-Optimized: TREE_GRAPH_HYBRID + WEIGHTED_GRAPH
- Persistence-Optimized: B_PLUS_TREE + EDGE_PROPERTY_STORE
- XWData-Optimized: HASH_MAP + None (DATA_INTERCHANGE)

## Results - 1x Scale

| Rank | Database | Node Mode | Edge Mode | Time | Memory | Ops/sec |
|------|----------|-----------|-----------|------|--------|----------|
| 1 * | Memory-Efficient | B_TREE | CSR | 13.22ms | 207.5MB | 3781462 |
| 2  | Query-Optimized | TREE_GRAPH_HYBRID | WEIGHTED_GRAPH | 13.99ms | 208.5MB | 3574288 |
| 3  | Read-Optimized | HASH_MAP | None | 14.20ms | 205.3MB | 3521300 |
| 4  | Persistence-Optimized | B_PLUS_TREE | EDGE_PROPERTY_STORE | 14.73ms | 209.4MB | 3395309 |
| 5  | Write-Optimized | LSM_TREE | DYNAMIC_ADJ_LIST | 14.96ms | 206.6MB | 3342693 |
| 6  | XWData-Optimized | HASH_MAP | None | 15.61ms | 210.5MB | 3203793 |

## Results - 10x Scale

| Rank | Database | Node Mode | Edge Mode | Time | Memory | Ops/sec |
|------|----------|-----------|-----------|------|--------|----------|
| 1 * | Write-Optimized | LSM_TREE | DYNAMIC_ADJ_LIST | 530.50ms | 224.6MB | 94251 |
| 2  | XWData-Optimized | HASH_MAP | None | 534.16ms | 264.1MB | 93604 |
| 3  | Persistence-Optimized | B_PLUS_TREE | EDGE_PROPERTY_STORE | 537.33ms | 254.0MB | 93053 |
| 4  | Query-Optimized | TREE_GRAPH_HYBRID | WEIGHTED_GRAPH | 537.66ms | 244.2MB | 92995 |
| 5  | Memory-Efficient | B_TREE | CSR | 547.24ms | 234.1MB | 91367 |
| 6  | Read-Optimized | HASH_MAP | None | 561.84ms | 214.6MB | 88994 |

## Key Findings

- **Fastest Overall**: Check rankings above
- **Most Memory Efficient**: Check memory column
- **Best for Production**: Query-Optimized or Write-Optimized
- **Best for xData**: XWData-Optimized

---

*Generated by Classic Database Benchmark*
